Template Attribute Language (TAL)
=================================

Overview
--------

The Zope3 Template Attribute Languate (TAL) specifies the custom namespace
and attributes which are used by the Zope Page Templates renderer to inject
dynamic markup into a page.  It also includes the Macro Expansion for TAL
(METAL) macro language used in page assembly.

The dynamic values themselves are specified using a companion language,
TALES (see the `zope.tales`_ package for more).

See: http://wiki.zope.org/ZPT/TALSpecification14

.. _`zope.tales` :  http://pypi.python.org/pypi/zope.tales